
from typing import Optional
import numpy as np
import gymnasium as gym
from solarcarsim.physsim import CarParams, DefaultCar





class SolarRaceV1(gym.Env):
    """ A primitive hill climber. Aims to solve the given route optimizing
        for energy usage and on-time arrival. Does not have wind or cloud simulations.
        Does simulate drag, rolling resistance, and slope power. The action space is the
        velocity of the car.
    """

    def __init__(self, car: CarParams = DefaultCar(), terrain = None, timestep: float = 1.0):
        # TODO: terrain parameters

        # car max speed.
        self.params = {
            "timestep": timestep,
            "car": car
        }

        self.observation_space = gym.spaces.Dict({
            "position": gym.spaces.Box(0, 1000.0, shape=(1,)),
            "time": gym.spaces.Box(0,1000),
            "energy": gym.spaces.Box(-1.0e6, 0.)
            # TODO: add the elevation profile to the observations.
        })

        self.action_space = gym.spaces.Box(0, 5.0, shape=(1,)) #velocity, m/s
